Class: Google::Apis::ReaderrevenuesubscriptionlinkingV1::Entitlement
- Inherits:
-
Object
- Object
- Google::Apis::ReaderrevenuesubscriptionlinkingV1::Entitlement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb
Overview
A single entitlement for a publication reader
Instance Attribute Summary collapse
-
#detail ⇒ String
The detail field can carry a description of the SKU that corresponds to what the user has been granted access to.
-
#expire_time ⇒ String
Optional.
-
#product_id ⇒ String
Required.
-
#subscription_token ⇒ String
A source-specific subscription token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Entitlement
constructor
A new instance of Entitlement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Entitlement
Returns a new instance of Entitlement.
72 73 74 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 72 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detail ⇒ String
The detail field can carry a description of the SKU that corresponds to what
the user has been granted access to. This description, which is opaque to
Google, can be displayed in the Google user subscription console for users who
linked the subscription to a Google Account. Max 80 character limit.
Corresponds to the JSON property detail
48 49 50 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 48 def detail @detail end |
#expire_time ⇒ String
Optional. Expiration time of the entitlement. If unset, the entitlement does
not expire (indefinite entitlement). We need to support indefinite
entitlements for platform publishers. dd: go/rrm-sl-notedotcom Entitlements
that have expired over 30 days will be purged.
Corresponds to the JSON property expireTime
56 57 58 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 56 def expire_time @expire_time end |
#product_id ⇒ String
Required. The publication's product ID that the user has access to. This is
the same product ID as can be found in Schema.org markup (http://schema.org/
productID). E.g. "dailybugle.com:basic"
Corresponds to the JSON property productId
63 64 65 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 63 def product_id @product_id end |
#subscription_token ⇒ String
A source-specific subscription token. This is an opaque string that the
publisher provides to Google. This token is opaque and has no meaning to
Google.
Corresponds to the JSON property subscriptionToken
70 71 72 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 70 def subscription_token @subscription_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77 78 79 80 81 82 |
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 77 def update!(**args) @detail = args[:detail] if args.key?(:detail) @expire_time = args[:expire_time] if args.key?(:expire_time) @product_id = args[:product_id] if args.key?(:product_id) @subscription_token = args[:subscription_token] if args.key?(:subscription_token) end |