Class: Google::Apis::ReaderrevenuesubscriptionlinkingV1::Reader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb

Overview

A reader of a publication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reader

Returns a new instance of Reader.



118
119
120
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time the publication reader was created and associated with a Google user. Corresponds to the JSON property createTime

Returns:

  • (String)


93
94
95
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 93

def create_time
  @create_time
end

#nameString

Output only. The resource name of the reader. The last part of ppid in the resource name is the publisher provided id. Corresponds to the JSON property name

Returns:

  • (String)


99
100
101
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 99

def name
  @name
end

#originating_publication_idString

Output only. The SwG publication id that the reader's subscription linking was originating from. Corresponds to the JSON property originatingPublicationId

Returns:

  • (String)


105
106
107
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 105

def originating_publication_id
  @originating_publication_id
end

#ppidString

Output only. The publisher provided id of the reader. Corresponds to the JSON property ppid

Returns:

  • (String)


110
111
112
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 110

def ppid
  @ppid
end

#publication_idString

Output only. The SwG publication id that the reader has linked their subscription to. Corresponds to the JSON property publicationId

Returns:

  • (String)


116
117
118
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 116

def publication_id
  @publication_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



123
124
125
126
127
128
129
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 123

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @originating_publication_id = args[:originating_publication_id] if args.key?(:originating_publication_id)
  @ppid = args[:ppid] if args.key?(:ppid)
  @publication_id = args[:publication_id] if args.key?(:publication_id)
end