Class: Google::Apis::ReaderrevenuesubscriptionlinkingV1::Reader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb,
lib/google/apis/readerrevenuesubscriptionlinking_v1/representations.rb

Overview

A reader of a publication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reader

Returns a new instance of Reader.



116
117
118
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time the publication reader was created and associated with a Google user. Corresponds to the JSON property createTime

Returns:

  • (String)


91
92
93
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 91

def create_time
  @create_time
end

#nameString

Output only. The resource name of the reader. The last part of ppid in the resource name is the publisher provided id. Corresponds to the JSON property name

Returns:

  • (String)


97
98
99
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 97

def name
  @name
end

#originating_publication_idString

Output only. The SwG publication id that the reader's subscription linking was originating from. Corresponds to the JSON property originatingPublicationId

Returns:

  • (String)


103
104
105
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 103

def originating_publication_id
  @originating_publication_id
end

#ppidString

Output only. The publisher provided id of the reader. Corresponds to the JSON property ppid

Returns:

  • (String)


108
109
110
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 108

def ppid
  @ppid
end

#publication_idString

Output only. The SwG publication id that the reader has linked their subscription to. Corresponds to the JSON property publicationId

Returns:

  • (String)


114
115
116
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 114

def publication_id
  @publication_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



121
122
123
124
125
126
127
# File 'lib/google/apis/readerrevenuesubscriptionlinking_v1/classes.rb', line 121

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @originating_publication_id = args[:originating_publication_id] if args.key?(:originating_publication_id)
  @ppid = args[:ppid] if args.key?(:ppid)
  @publication_id = args[:publication_id] if args.key?(:publication_id)
end